@@ -31,7 +31,7 @@ from cachecontrol import CacheControl, adapter
 from cachecontrol.caches.file_cache import FileCache
 #import requests_cache
 import logging
-#LOGGER = logging.getLogger('dax')
+LOGGER = logging.getLogger('dax')
 from datetime import datetime
 import time
 DEBUG = False
@@ -268,6 +268,8 @@ class Interface(object):
                 self._jsession = 'JSESSIONID=' + self._exec('/data/JSESSION', force_preemptive_auth=True)
                 self._entry = '/data'
 
+		LOGGER.warn("pyxnat get_entry:%s" % self._jsession)
+                print("pyxnat:%s" % self._jsession)
                 if is_xnat_error(self._jsession):
                     catch_error(self._jsession)
             except Exception as e:
@@ -354,10 +356,16 @@ class Interface(object):
         if headers is None:
             headers = {}
         #headers = {'Cache-Control: Public'}
+	LOGGER.warn('SHUNXING %s URI: %s' % (method,str(uri)))
         self._get_entry_point()
 
         uri = join_uri(self._server, uri)
+	
+        # SHUNXING FOR debugging
         
+	if 'JSESSION' in str(uri):
+	    LOGGER.warn("SHUNXING %s URI: %s; JSESSION:%s" % (method,str(uri),self._jsession))
+	    print('%s URI: %s; JSESSION:%s' % (method,str(uri),self._jsession))
         #LOGGER.warn('SHUNXING URI:%s' % str(uri))
 
         if DEBUG:
